@@ -20,8 +20,13 @@ extern reiser4_format_t *reiser4_format_create(reiser4_fs_t *fs,
 					       reiser4_format_plug_t *plug,
 					       rid_t policy,
 					       rid_t key,
+					       rid_t key_alloc,
 					       rid_t node,
-					       count_t blocks);
+					       count_t blocks,
+					       long int mkfs_id,
+					       uint64_t subvol_id,
+					       uint64_t num_subvols,
+					       uint8_t nr_sgs_bits);
 
 extern errno_t reiser4_format_backup(reiser4_format_t *format,
 				     backup_hint_t *hint);
