@@ -93,7 +93,7 @@ struct reiser4_plug {
  * NOTE: Make sure that respective marco is also incremented in
  * the new release of reiser4 kernel module.
  */
-#define PLUGIN_LIBRARY_VERSION 2
+#define PLUGIN_LIBRARY_VERSION 3
 
 /* Known by library plugin types. */
 typedef enum reiser4_plug_type {
@@ -121,6 +121,9 @@ typedef enum reiser4_plug_type {
 	/* Not really a plugin, at least in progs, but a value that 
 	   needs to be checked only. */
 	PARAM_PLUG_TYPE		= 0x12,
+	DST_PLUG_TYPE           = 0x13,
+	VOL_PLUG_TYPE           = 0x14,
+	KEYALLOC_PLUG_TYPE      = 0x15,
 	LAST_PLUG_TYPE
 } reiser4_plug_type_t;
 
@@ -131,6 +134,7 @@ enum reiser4_object_plug_id {
 	OBJECT_SYM40_ID		= 0x2,
 	OBJECT_SPL40_ID	        = 0x3,
 	OBJECT_CCREG40_ID	= 0x4,
+	OBJECT_REG42_ID 	= 0x5,
 	OBJECT_LAST_ID
 };
 
@@ -154,6 +158,7 @@ enum reiser4_item_plug_id {
 	ITEM_PLAIN40_ID		= 0x6,
 	ITEM_CTAIL40_ID		= 0x7,
 	ITEM_BLACKBOX40_ID	= 0x8,
+	ITEM_EXTENT41_ID	= 0x9,
 	ITEM_LAST_ID
 };
 
@@ -215,6 +220,7 @@ enum reiser4_sdext_plug_id {
 /* Known format plugin ids. */
 enum reiser4_format_plug_id {
 	FORMAT_REISER40_ID	= 0x0,
+	FORMAT_REISER41_ID	= 0x1,
 	FORMAT_LAST_ID
 };
 
@@ -245,6 +251,13 @@ enum reiser4_key_plug_id {
 	KEY_LAST_ID
 };
 
+/* Known key allocation schemes */
+enum reiser4_key_alloc_plug_id {
+	KEYALLOC_PLANA_ID	= 0x0,
+	KEYALLOC_PLANB_ID	= 0x1,
+	KEYALLOC_LAST_ID
+};
+
 typedef struct reiser4_plug reiser4_plug_t;
 
 enum reiser4_fibre_plug_id {
@@ -298,6 +311,18 @@ enum reiser4_digest_id {
 	DIGEST_LAST_ID
 };
 
+enum reiser4_distribution_id {
+	DST_TRIV_ID  = 0x0,
+	DST_FSX32_ID = 0x1,
+	DST_LAST_ID
+};
+
+enum reiser4_volume_id {
+	VOL_SIMPLE_ID = 0x0,
+	VOL_ASYM_ID = 0x1,
+	VOL_LAST_ID
+};
+
 #define INVAL_PTR	        ((void *)-1)
 #define INVAL_PID	        ((rid_t)~0)
 
@@ -421,6 +446,7 @@ typedef struct reiser4_node reiser4_node_t;
 typedef struct reiser4_place reiser4_place_t;
 
 typedef struct reiser4_key_plug reiser4_key_plug_t;
+typedef struct reiser4_keyalloc_plug reiser4_keyalloc_plug_t;
 typedef struct reiser4_item_plug reiser4_item_plug_t;
 typedef struct reiser4_node_plug reiser4_node_plug_t;
 typedef struct reiser4_hash_plug reiser4_hash_plug_t;
@@ -954,10 +980,16 @@ enum format_hint_mask {
 };
 
 typedef struct format_hint {
+	uint64_t subvol_id;
+	uint64_t num_subvols;
 	uint64_t blocks;
 	uint32_t blksize;
+	uint16_t num_sgs_bits;
+	uint64_t data_capacity;
+	long int mkfs_id;
 	rid_t policy;
 	rid_t key;
+	rid_t key_alloc;
 	rid_t node;
 
 	/* For repair purposes. Set plugin types that are overridden 
@@ -1051,6 +1083,9 @@ struct reiser4_key_plug {
 #endif
 };
 
+struct reiser4_keyalloc_plug {
+	reiser4_plug_t p;
+};
 
 typedef struct reiser4_object_plug {
 	reiser4_plug_t p;
@@ -1479,6 +1514,8 @@ struct reiser4_format_plug {
 	void (*set_len) (reiser4_format_ent_t *, uint64_t);
 	void (*set_root) (reiser4_format_ent_t *, uint64_t);
 	void (*set_free) (reiser4_format_ent_t *, uint64_t);
+	void (*set_data_capacity) (reiser4_format_ent_t *, uint64_t);
+	void (*set_min_occup) (reiser4_format_ent_t *, uint64_t);
 	void (*set_stamp) (reiser4_format_ent_t *, uint32_t);
 	void (*set_policy) (reiser4_format_ent_t *, rid_t);
 	void (*set_height) (reiser4_format_ent_t *, uint16_t);
@@ -1693,7 +1730,7 @@ struct reiser4_journal_plug {
 	void (*set_state) (reiser4_journal_ent_t *, uint32_t);
 	
 	/* Replays the journal */
-	errno_t (*replay) (reiser4_journal_ent_t *);
+	errno_t (*replay) (reiser4_journal_ent_t *, uint64_t *);
 
 	/* Prints journal content */
 	void (*print) (reiser4_journal_ent_t *, aal_stream_t *, uint16_t);
@@ -1723,9 +1760,19 @@ typedef struct reiser4_policy_plug {
 	int (*tails) (uint64_t);
 } reiser4_policy_plug_t;
 
+/* Volume plugin */
+typedef struct reiser4_vol_plug {
+	reiser4_plug_t p;
+	int (*advise_stripe_size)(uint64_t *result, uint64_t block_count,
+				  uint32_t block_size, int is_default,
+				  int forced);
+	int (*advise_nr_segments)(uint64_t *result, int forced);
+	int (*check_data_capacity)(uint64_t result, uint64_t block_count,
+				    int forced);
+  uint64_t (*default_data_capacity)(uint64_t free_blocks, int is_data_brick);
+} reiser4_vol_plug_t;
 #endif
 
-
 typedef struct reiser4_core reiser4_core_t;
 
 /* Plugin init() and fini() function types. They are used for calling these
