@@ -15,9 +15,10 @@
 #define REISER4_FS_MIN_SIZE(blksize) \
 	(9 + REISER4_MASTER_BLOCKNR(blksize))
 
-/* Master super block structure. It is the same for all reiser4 filesystems,
-   so, we can declare it here. It contains common for all format fields like
-   block size etc. */
+/*
+ * Master super-block is a collection of parameters
+ * which never get changed during volume's life
+ */
 typedef struct reiser4_master_sb {
 	/* Master super block magic. */
 	char ms_magic[16];
@@ -28,11 +29,20 @@ typedef struct reiser4_master_sb {
 	/* Filesyetem block size in use. */
 	d16_t ms_blksize;
 
-	/* Filesyetm uuid in use. */
-	char ms_uuid[16];
+	/* Logical volume uuid */
+	char ms_vol_uuid[16];
 
 	/* Filesystem label in use. */
 	char ms_label[16];
+
+	/* Reiser5 fields */
+ 	char ms_sub_uuid[16];   /* subvolume's external id (per subolvume) */
+	d16_t ms_volume_pid;    /* volume plugin id (per volume) */
+	d16_t ms_distrib_pid;   /* distribution plugin id (per volume) */
+	d16_t ms_mirror_id;     /* id of the mirror, 0 for original */
+	d16_t ms_num_replicas;  /* number of replicas. Replica is a mirror,
+				   of id, which is different from 0 */
+	d8_t ms_stripe_bits;    /* logarithm of stripe size (per volume) */
 } reiser4_master_sb_t;
 
 #define get_ms_format(ms)        aal_get_le16(ms, ms_format)
@@ -41,6 +51,28 @@ typedef struct reiser4_master_sb {
 #define get_ms_blksize(ms)       aal_get_le16(ms, ms_blksize)
 #define set_ms_blksize(ms, val)  aal_set_le16(ms, ms_blksize, val)
 
+#define get_ms_volume_pid(ms)       aal_get_le16(ms, ms_volume_pid)
+#define set_ms_volume_pid(ms, val)  aal_set_le16(ms, ms_volume_pid, val)
+
+#define get_ms_distrib_pid(ms)       aal_get_le16(ms, ms_distrib_pid)
+#define set_ms_distrib_pid(ms, val)  aal_set_le16(ms, ms_distrib_pid, val)
+
+#define get_ms_mirror_id(ms)       aal_get_le16(ms, ms_mirror_id)
+#define set_ms_mirror_id(ms, val)  aal_set_le16(ms, ms_mirror_id, val)
+
+#define get_ms_num_replicas(ms)       aal_get_le16(ms, ms_num_replicas)
+#define set_ms_num_replicas(ms, val)  aal_set_le16(ms, ms_num_replicas, val)
+
+static inline d8_t get_ms_stripe_bits(reiser4_master_sb_t *ms)
+{
+	return ms->ms_stripe_bits;
+}
+
+static inline void set_ms_stripe_bits(reiser4_master_sb_t *ms, d8_t val)
+{
+	ms->ms_stripe_bits = val;
+}
+
 #define SS_MAGIC_SIZE	16
 #define SS_STACK_SIZE	10
 #define SS_MESSAGE_SIZE 256
@@ -93,6 +125,11 @@ enum reiser4_state {
 	FS_IO		= 1 << 3
 };
 
+enum reiser4_extended_state {
+	FSE_OK = 0,
+	FSE_MIRRORS_NOT_SYNCED = 1 << 0
+};
+
 typedef struct reiser4_master {
 	/* Flag for marking master dirty */
 	bool_t dirty;
@@ -280,8 +317,18 @@ struct reiser4_fs {
 typedef struct fs_hint {
 	count_t blocks;
 	uint32_t blksize;
-	char uuid[17];
+	char volume_uuid[17];
+	char subvol_uuid[17];
 	char label[17];
+	int is_data_brick;
+	long int mkfs_id;
+	uint64_t subvol_id;
+	uint64_t num_subvols;
+	uint16_t mirror_id;
+	uint16_t num_replicas;
+	uint64_t stripe_size;
+	uint64_t num_segments;
+	uint64_t data_capacity;
 } fs_hint_t;
 
 typedef void (*uuid_unparse_t) (char *uuid, char *string);
@@ -289,3 +336,13 @@ typedef errno_t (*walk_func_t) (reiser4_tree_t *, reiser4_node_t *);
 typedef errno_t (*walk_on_func_t) (reiser4_tree_t *, reiser4_place_t *);
 
 #endif
+
+/*
+ * Local variables:
+ * c-indentation-style: "K&R"
+ * mode-name: "LC"
+ * c-basic-offset: 8
+ * tab-width: 8
+ * fill-column: 80
+ * End:
+ */
