@@ -11,8 +11,11 @@
 extern errno_t repair_status_pack(reiser4_status_t *status, 
 				  aal_stream_t *stream);
 
-extern void repair_status_state(reiser4_status_t *status,
-				uint64_t state);
+extern void repair_status_update(reiser4_status_t *status,
+				 uint64_t state);
+
+extern void repair_status_extended_update(reiser4_status_t *status,
+					  uint64_t ext_state);
 
 extern errno_t repair_status_open(reiser4_fs_t *fs, uint8_t mode);
 
