@@ -25,6 +25,9 @@ static uint8_t plugs_max[LAST_PLUG_TYPE + 1] = {
 	[COMPRESS_PLUG_TYPE]	= COMPRESS_LAST_ID,
 	[CMODE_PLUG_TYPE]	= CMODE_LAST_ID,
 	[CLUSTER_PLUG_TYPE]	= CLUSTER_LAST_ID,
+	[DST_PLUG_TYPE]         = DST_LAST_ID,
+	[VOL_PLUG_TYPE]         = VOL_LAST_ID,
+	[KEYALLOC_PLUG_TYPE]	= KEYALLOC_LAST_ID,
 	[LAST_PLUG_TYPE]	= 0,
 };
 
@@ -142,7 +145,9 @@ errno_t reiser4_factory_init(void) {
 	
 	/* Registering all known plugins. */
 	__load_plug(format40);
+	__load_plug(format41);
 	__init_plug(format40);
+	__init_plug(format41);
 
 #ifndef ENABLE_MINIMAL
 	__load_plug(oid40);
@@ -222,6 +227,8 @@ errno_t reiser4_factory_init(void) {
 #endif
 	__load_plug(extent40);
 	__init_plug(extent40);
+
+	__load_plug(extent41);
 	
 	__load_plug(nodeptr40);
 	__init_plug(nodeptr40);
@@ -236,7 +243,9 @@ errno_t reiser4_factory_init(void) {
 #ifdef ENABLE_SHORT_KEYS
 	__load_plug(key_short);
 #endif
-	
+	__load_plug(keyalloc_plana);
+	__load_plug(keyalloc_planb);
+
 	__load_plug(node40);
 	__init_plug(node40);
 
@@ -244,6 +253,7 @@ errno_t reiser4_factory_init(void) {
 	
 	__load_plug(dir40);
 	__load_plug(reg40);
+	__load_plug(reg42);
 	
 #ifdef ENABLE_SPECIAL
 	__load_plug(spl40);
@@ -282,6 +292,12 @@ errno_t reiser4_factory_init(void) {
 	__load_plug(clust16);
 	__load_plug(clust8);
 	__load_plug(clust4);
+
+	__load_plug(triv_dst);
+	__load_plug(fsx32);
+
+	__load_plug(simple_vol);
+	__load_plug(asym_vol);
 #endif
 
         return 0;
