@@ -4,6 +4,7 @@
    filesystem.c -- common reiser4 filesystem code. */
 
 #include <reiser4/libreiser4.h>
+#include <misc/misc.h>
 
 /* Opens filesystem on specified device */
 
@@ -250,7 +251,7 @@ reiser4_fs_t *reiser4_fs_create(
 	aal_device_t *device,           /* device filesystem will be lie on */
 	fs_hint_t *hint)                /* filesystem hint */
 {
-  reiser4_plug_t *format, *policy, *node, *key;
+	reiser4_plug_t *vol, *dist, *format, *policy, *node, *key, *key_alloc;
 
 	count_t free;
 	reiser4_fs_t *fs;
@@ -272,6 +273,9 @@ reiser4_fs_t *reiser4_fs_create(
 	fs->device = device;
 		
 	/* Create master super block. */
+
+	vol = reiser4_profile_plug(PROF_VOL);
+	dist = reiser4_profile_plug(PROF_DST);
 	format = reiser4_profile_plug(PROF_FORMAT);
 		
 	if (!(fs->master = reiser4_master_create(device, hint)))
@@ -280,7 +284,9 @@ reiser4_fs_t *reiser4_fs_create(
 	if (reiser4_format_check_len(device, hint->blksize, hint->blocks))
 		goto error_free_master;
 
-	/* Setting up master super block. */
+	/* Set volume, distribution and format id to the master super block */
+	reiser4_master_set_volume(fs->master, vol->id.id);
+	reiser4_master_set_dist(fs->master, dist->id.id);
 	reiser4_master_set_format(fs->master, format->id.id);
 
 	if (!(fs->status = reiser4_status_create(device, hint->blksize)))
@@ -294,13 +300,18 @@ reiser4_fs_t *reiser4_fs_create(
 
 	/* Taking care about key flags in format super block */
 	key = reiser4_profile_plug(PROF_KEY);
-	
+	key_alloc = reiser4_profile_plug(PROF_KEYALLOC);
+
 	/* Creates disk format. */
 	
 	fs->format = reiser4_format_create(fs, (reiser4_format_plug_t *)format,
 					   policy->id.id, key->id.id,
-					   node->id.id, hint->blocks);
-	if (!fs->format) 
+					   key_alloc->id.id,
+					   node->id.id, hint->blocks,
+					   hint->mkfs_id, hint->subvol_id,
+					   hint->num_subvols,
+					   hint->num_segments ? misc_log2(hint->num_segments) : 0);
+	if (!fs->format)
 		goto error_free_status;
 
 	/* Creates block allocator */
@@ -341,6 +352,27 @@ reiser4_fs_t *reiser4_fs_create(
 	return NULL;
 }
 
+void reiser4_set_data_capacity(reiser4_fs_t *fs, fs_hint_t *hint)
+{
+	if (hint->data_capacity == 0) {
+		reiser4_vol_plug_t *vol = reiser4_profile_plug(PROF_VOL);
+		uint64_t free = reiser4_format_get_free(fs->format);
+		hint->data_capacity = plugcall(vol, default_data_capacity,
+					       free, hint->is_data_brick);
+	}
+	reiser4_format_set_data_capacity(fs->format, hint->data_capacity);
+}
+
+/**
+ * This is called at the end of the procedure of formatting a partition
+ */
+void reiser4_set_min_occup(reiser4_fs_t *fs)
+{
+	reiser4_format_set_min_occup(fs->format,
+				     reiser4_format_get_len(fs->format) -
+				     reiser4_format_get_free(fs->format));
+}
+
 /* Backup the fs -- save all permanent info about the fs info the memory stream
    to be backed up somewhere on the fs. */
 errno_t reiser4_fs_backup(reiser4_fs_t *fs, backup_hint_t *hint) {
