@@ -87,8 +87,13 @@ reiser4_format_t *reiser4_format_create(
 	reiser4_format_plug_t *plug,	/* format plugin */
 	rid_t policy,			/* policy plug id */
 	rid_t key,			/* key plug id */
+	rid_t key_alloc,		/* key allocation scheme */
 	rid_t node,                     /* node plug id */
-	count_t blocks)			/* block count */
+	count_t blocks,			/* block count */
+	long int mkfs_id,               /* identifier for fsck */
+	uint64_t subvol_id,             /* internal id */
+	uint64_t num_subvols,           /* in the logical volume */
+	uint8_t num_segments_bits)
 {
 	reiser4_format_t *format;
 	format_hint_t desc;
@@ -107,11 +112,17 @@ reiser4_format_t *reiser4_format_create(
 	desc.blocks = blocks;
 	desc.policy = policy;
 	desc.key = key;
+	desc.key_alloc = key_alloc;
 	desc.node = node;
-
-	/* Initializing entity of disk-format by means of calling "create"
-	   method from found plugin. Plugin "create" method will be creating 
-	   all disk structures, namely, format-specific super block. */
+	desc.mkfs_id = mkfs_id;
+	desc.subvol_id = subvol_id;
+	desc.num_subvols = num_subvols;
+	desc.num_sgs_bits = num_segments_bits;
+	/*
+	 * Initializing entity of disk-format by means of calling "create"
+	 * method from found plugin. Plugin "create" method will be creating
+	 * all disk structures, namely, format-specific super block
+	 */
 	if (!(format->ent = plugcall(plug, create, fs->device, &desc))) {
 		aal_error("Can't create format %s on %s.",
 			  plug->p.label, fs->device->name);
@@ -305,6 +316,26 @@ void reiser4_format_set_free(
 	reiser4call(format, set_free, blocks);
 }
 
+/* Sets data room size in blocks */
+void reiser4_format_set_data_capacity(
+	reiser4_format_t *format,	/* format to be used */
+	count_t blocks)		        /* new free block count */
+{
+	aal_assert("edward-32", format != NULL);
+
+	reiser4call(format, set_data_capacity, blocks);
+}
+
+/* Sets minimal occupied number of blocks on a partition */
+void reiser4_format_set_min_occup(
+	reiser4_format_t *format,	/* format to be used */
+	count_t blocks)		        /* value to set */
+{
+	aal_assert("edward-34", format != NULL);
+
+	reiser4call(format, set_min_occup, blocks);
+}
+
 /* Sets new tree height */
 void reiser4_format_set_height(
 	reiser4_format_t *format,	/* format to be used */
