@@ -4,6 +4,7 @@
    master.c -- master super block functions. */
 
 #include <aux/aux.h>
+#include <misc/misc.h>
 #include <reiser4/libreiser4.h>
 
 #ifndef ENABLE_MINIMAL
@@ -37,9 +38,9 @@ errno_t reiser4_master_valid(reiser4_master_t *master) {
 /* Forms master super block disk structure */
 reiser4_master_t *reiser4_master_create(aal_device_t *device, fs_hint_t *hint) {
 	reiser4_master_t *master;
-    
+
 	aal_assert("umka-981", device != NULL);
-    
+
 	/* Allocating the memory for master super block struct */
 	if (!(master = aal_calloc(sizeof(*master), 0)))
 		return NULL;
@@ -47,12 +48,15 @@ reiser4_master_t *reiser4_master_create(aal_device_t *device, fs_hint_t *hint) {
 	/* Setting up magic. */
 	aal_strncpy(SUPER(master)->ms_magic, REISER4_MASTER_MAGIC,
 		    sizeof(REISER4_MASTER_MAGIC));
-    
-	/* Setting up block filesystem used */
-	set_ms_blksize(SUPER(master), hint->blksize);
-	reiser4_master_set_uuid(master, hint->uuid);
-	reiser4_master_set_label(master, hint->label);
 
+	set_ms_blksize(SUPER(master), hint->blksize);
+	reiser4_master_set_volume_uuid(master, hint->volume_uuid);
+	reiser4_master_set_subvol_uuid(master, hint->subvol_uuid);
+	reiser4_master_set_mirror_id(master, hint->mirror_id);
+	reiser4_master_set_num_replicas(master, hint->num_replicas);
+	reiser4_master_set_label(master, hint->label);
+	reiser4_master_set_stripe_bits(master, hint->stripe_size ?
+				       misc_log2(hint->stripe_size) : 0);
 	master->dirty = 1;
 	master->device = device;
 	
@@ -260,9 +264,14 @@ char *reiser4_master_get_magic(reiser4_master_t *master) {
 	return SUPER(master)->ms_magic;
 }
 
-char *reiser4_master_get_uuid(reiser4_master_t *master) {
+char *reiser4_master_get_volume_uuid(reiser4_master_t *master) {
 	aal_assert("umka-984", master != NULL);
-	return SUPER(master)->ms_uuid;
+	return SUPER(master)->ms_vol_uuid;
+}
+
+char *reiser4_master_get_subvol_uuid(reiser4_master_t *master) {
+	aal_assert("edward-20", master != NULL);
+	return SUPER(master)->ms_sub_uuid;
 }
 
 char *reiser4_master_get_label(reiser4_master_t *master) {
@@ -270,6 +279,36 @@ char *reiser4_master_get_label(reiser4_master_t *master) {
 	return SUPER(master)->ms_label;
 }
 
+uint16_t reiser4_master_get_mirror_id(reiser4_master_t *master) {
+	aal_assert("edward-21", master != NULL);
+	return get_ms_mirror_id(SUPER(master));
+}
+
+unsigned char reiser4_master_get_stripe_bits(reiser4_master_t *master)
+{
+	aal_assert("edward-26", master != NULL);
+	return get_ms_stripe_bits(SUPER(master));
+}
+
+uint16_t reiser4_master_is_replica(reiser4_master_t *master) {
+	return reiser4_master_get_mirror_id(master);
+}
+
+uint16_t reiser4_master_get_num_replicas(reiser4_master_t *master) {
+	aal_assert("edward-22", master != NULL);
+	return get_ms_num_replicas(SUPER(master));
+}
+
+rid_t reiser4_master_get_dist(reiser4_master_t *master) {
+	aal_assert("edward-28", master != NULL);
+	return get_ms_distrib_pid(SUPER(master));
+}
+
+rid_t reiser4_master_get_volume(reiser4_master_t *master) {
+	aal_assert("edward-29", master != NULL);
+	return get_ms_volume_pid(SUPER(master));
+}
+
 void reiser4_master_set_format(reiser4_master_t *master,
 			       rid_t format)
 {
@@ -286,18 +325,57 @@ void reiser4_master_set_blksize(reiser4_master_t *master,
 	master->dirty = 1;
 }
 
-void reiser4_master_set_uuid(reiser4_master_t *master,
-			     char *uuid)
+void reiser4_master_set_mirror_id(reiser4_master_t *master,
+				  uint16_t mirror_id)
+{
+	aal_assert("edward-23", master != NULL);
+	set_ms_mirror_id(SUPER(master), mirror_id);
+	master->dirty = 1;
+}
+
+void reiser4_master_set_stripe_bits(reiser4_master_t *master,
+				    uint8_t stripe_bits)
+{
+	aal_assert("edward-27", master != NULL);
+	set_ms_stripe_bits(SUPER(master), stripe_bits);
+	master->dirty = 1;
+}
+
+void reiser4_master_set_num_replicas(reiser4_master_t *master,
+				  uint16_t num_replicas)
+{
+	aal_assert("edward-24", master != NULL);
+	set_ms_num_replicas(SUPER(master), num_replicas);
+	master->dirty = 1;
+}
+
+void reiser4_master_set_volume_uuid(reiser4_master_t *master,
+				    char *uuid)
 {
 	aal_assert("umka-2498", master != NULL);
 
-	aal_memset(SUPER(master)->ms_uuid, 0,
-		   sizeof(SUPER(master)->ms_uuid));
+	aal_memset(SUPER(master)->ms_vol_uuid, 0,
+		   sizeof(SUPER(master)->ms_vol_uuid));
 	
 	if (uuid) {
-		aal_memcpy(SUPER(master)->ms_uuid, uuid,
-			   sizeof(SUPER(master)->ms_uuid));
-	} 
+		aal_memcpy(SUPER(master)->ms_vol_uuid, uuid,
+			   sizeof(SUPER(master)->ms_vol_uuid));
+	}
+	master->dirty = 1;
+}
+
+void reiser4_master_set_subvol_uuid(reiser4_master_t *master,
+				    char *uuid)
+{
+	aal_assert("edward-25", master != NULL);
+
+	aal_memset(SUPER(master)->ms_sub_uuid, 0,
+		   sizeof(SUPER(master)->ms_sub_uuid));
+
+	if (uuid) {
+		aal_memcpy(SUPER(master)->ms_sub_uuid, uuid,
+			   sizeof(SUPER(master)->ms_sub_uuid));
+	}
 	master->dirty = 1;
 }
 
@@ -316,4 +394,18 @@ void reiser4_master_set_label(reiser4_master_t *master,
 	master->dirty = 1;
 }
 
+void reiser4_master_set_dist(reiser4_master_t *master, rid_t dist)
+{
+	aal_assert("edward-30", master != NULL);
+	set_ms_distrib_pid(SUPER(master), dist);
+	master->dirty = 1;
+}
+
+void reiser4_master_set_volume(reiser4_master_t *master, rid_t vol)
+{
+	aal_assert("edward-31", master != NULL);
+	set_ms_volume_pid(SUPER(master), vol);
+	master->dirty = 1;
+}
+
 #endif
