@@ -37,7 +37,7 @@ reiser4_profile_t defprof = {
 			.hidden = 1,
 			.max = OBJECT_LAST_ID,
 #endif
-			.id = {OBJECT_REG40_ID, REG_OBJECT, OBJECT_PLUG_TYPE},
+			.id = {OBJECT_REG42_ID, REG_OBJECT, OBJECT_PLUG_TYPE},
 		},
 		[PROF_DIRFILE] = {
 #ifndef ENABLE_MINIMAL
@@ -73,16 +73,16 @@ reiser4_profile_t defprof = {
 			.hidden = 0,
                         .max = OBJECT_LAST_ID,
 #endif
-                        .id = {OBJECT_CCREG40_ID, REG_OBJECT, OBJECT_PLUG_TYPE},
+                        .id = {OBJECT_REG42_ID, REG_OBJECT, OBJECT_PLUG_TYPE},
                 },
 		[PROF_FORMAT] = {
 #ifndef ENABLE_MINIMAL
 			.name  = "format",
-			.desc  = "",
-			.hidden = 1,
+			.desc  = "Standard layout for logical volumes",
+			.hidden = 0,
 			.max = FORMAT_LAST_ID,
 #endif
-			.id = {FORMAT_REISER40_ID, 0, FORMAT_PLUG_TYPE},
+			.id = {FORMAT_REISER41_ID, 0, FORMAT_PLUG_TYPE},
 		},
 		[PROF_JOURNAL] = {
 #ifndef ENABLE_MINIMAL
@@ -120,6 +120,15 @@ reiser4_profile_t defprof = {
 #endif
 			.id = {KEY_LARGE_ID, 0, KEY_PLUG_TYPE},
 		},
+		[PROF_KEYALLOC] = {
+#ifndef ENABLE_MINIMAL
+			.name  = "keyalloc",
+			.desc  = "Key allocation scheme",
+			.hidden = 0,
+			.max = KEYALLOC_LAST_ID,
+#endif
+			.id = {KEYALLOC_PLANB_ID, 0, KEYALLOC_PLUG_TYPE},
+		},
 		[PROF_NODE] = {
 #ifndef ENABLE_MINIMAL
 			.name  = "node",
@@ -228,6 +237,24 @@ reiser4_profile_t defprof = {
 #endif
 			.id = {ITEM_CDE40_ID, DIR_ITEM, ITEM_PLUG_TYPE},
 		},
+		[PROF_DST] = {
+#ifndef ENABLE_MINIMAL
+			.name  = "dist",
+			.desc  = "Distribution plugin",
+			.hidden = 0,
+			.max = DST_LAST_ID,
+#endif
+			.id = {DST_FSX32_ID, 0, DST_PLUG_TYPE},
+		},
+		[PROF_VOL] = {
+#ifndef ENABLE_MINIMAL
+			.name  = "vol",
+			.desc  = "Volume plugin",
+			.hidden = 0,
+			.max = VOL_LAST_ID,
+#endif
+			.id = {VOL_ASYM_ID, 0, VOL_PLUG_TYPE},
+		},
 #ifndef ENABLE_MINIMAL
 		[PROF_NODEPTR] = {
 			.name  = "nodeptr",
