@@ -402,7 +402,7 @@ static errno_t fsck_check_init(repair_data_t *repair,
 		}
 	}
 	
-	if ((res = repair_fs_replay(repair->fs)) < 0)
+	if ((res = repair_fs_replay(repair->fs, &repair->num_replayed_tx)) < 0)
 		goto error_close_fs;
 	
 	repair_error_count(repair, res);
@@ -434,17 +434,15 @@ static errno_t fsck_check_init(repair_data_t *repair,
 	
 	repair_master_print(repair->fs->master, &stream, 
 			    misc_uuid_unparse);
-	
 	aal_stream_format(&stream, "\n");
-	
+
 	repair_format_print(repair->fs->format, &stream);
 	aal_stream_format(&stream, "\n");
 	
 	aal_mess("Reiser4 fs was detected on %s.\n%s",
 		repair->fs->device->name, (char *)stream.entity);
-	
 	aal_stream_fini(&stream);
-	
+
 	/* Initialize the backup. */
 	len = reiser4_format_get_len(repair->fs->format);
 	if ((res = backup_init(backup, host, len)))
@@ -486,10 +484,13 @@ static errno_t fsck_check_fini(repair_data_t *repair,
 	} else if (repair->fixable || repair->sb_fixable) {
 		state = FS_CORRUPTED;
 	} else {
-		state = 0;
+		state = FS_OK;
 	}
+	repair_status_update(status, state);
 
-	repair_status_state(status, state);
+	if (state != FS_OK || repair->num_replayed_tx != 0)
+		/* fsck doesn't work with mirrors */
+		repair_status_extended_update(status, FSE_MIRRORS_NOT_SYNCED);
 
 	if (reiser4_status_sync(repair->fs->status))
 		return -EIO;
@@ -619,7 +620,7 @@ int main(int argc, char *argv[]) {
 		} else {
 			fprintf(stderr, "%llu fatal corruptions were detected in %s. "
 				"Run with %s option to fix them.\n",
-				(unsigned long long)repair.fatal, 
+				(unsigned long long)repair.fatal,
 				stage ? "FileSystem" : "SuperBlock", 
 				stage ? "--build-fs" : "--build-sb");
 		}
