@@ -11,6 +11,11 @@
 #  include <uuid/uuid.h>
 #endif
 
+#ifndef ENABLE_MINIMAL
+#  include <time.h>
+#  include <stdlib.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <fcntl.h>
@@ -35,20 +40,25 @@ typedef enum mkfs_behav_flags {
 	BF_LOST       = 1 << 2,
 	BF_SHOW_PARM  = 1 << 3,
 	BF_SHOW_PLUG  = 1 << 4,
-	BF_DISCARD    = 1 << 5
+	BF_DISCARD    = 1 << 5,
+	BF_MIRRORS    = 1 << 6
 } mkfs_behav_flags_t;
 
 /* Prints mkfs options */
 static void mkfs_print_usage(char *name) {
 	fprintf(stderr, "Usage: %s [ options ] "
 		"FILE1 FILE2 ... [ size[K|M|G] ]\n", name);
-    
+
 	fprintf(stderr, 
 		"Mkfs options:\n"
 		"  -s, --lost-found              forces mkfs to create lost+found\n"
 		"                                directory.\n"
+		"  -a, --data-brick              forces mkfs to create data bricks.\n"
 		"  -b, --block-size N            block size, 4096 by default, other\n"
 		"                                are not supported at the moment.\n"
+		"  -t, --stripe-size N           stripe size [K|M|G].\n"
+		"  -n, --nr-segments N           number of hash space segments\n"
+		"  -c, --data-capacity N         data capacity of the brick.\n"
 		"  -U, --uuid UUID               universally unique identifier.\n"
 		"  -L, --label LABEL             volume label lets to mount\n"
 		"                                filesystem by its label.\n"
@@ -65,7 +75,8 @@ static void mkfs_print_usage(char *name) {
 		"  -f, --force                   makes mkfs to use whole disk, not\n"
 		"                                block device or mounted partition.\n"
 		"  -d, --discard                 tells mkfs to discard given device\n"
-		"                                before creating the filesystem (for SSDs).\n");
+		"                                before creating the filesystem (for SSDs)\n"
+		"  -m, --mirrors                 create mirrors on listed devices.\n");
 }
 
 /* Initializes used by mkfs exception streams */
@@ -97,10 +108,31 @@ static reiser4_object_t *reiser4_root_create(reiser4_fs_t *fs) {
 	return reiser4_object_create(&entry, &info, NULL);
 }
 
+static int advise_stripe_size(fs_hint_t *hint, int is_default, int forced)
+{
+	return plugcall((reiser4_vol_plug_t *)reiser4_profile_plug(PROF_VOL),
+			advise_stripe_size, &hint->stripe_size,
+			hint->blksize, hint->blocks, is_default,
+			forced);
+}
+
+static int advise_nr_segments(fs_hint_t *hint, int forced)
+{
+	return plugcall((reiser4_vol_plug_t *)reiser4_profile_plug(PROF_VOL),
+			advise_nr_segments, &hint->num_segments, forced);
+}
+
+static int check_data_capacity(fs_hint_t *hint, int forced)
+{
+	return plugcall((reiser4_vol_plug_t *)reiser4_profile_plug(PROF_VOL),
+			check_data_capacity, hint->data_capacity,
+			hint->blocks, forced);
+}
+
 int main(int argc, char *argv[]) {
 	int c;
 	struct stat st;
-	
+
 	fs_hint_t hint;
 	reiser4_fs_t *fs;
 	char override[4096];
@@ -109,22 +141,26 @@ int main(int argc, char *argv[]) {
 	aal_list_t *walk = NULL;
 	aal_gauge_t *gauge = NULL;
 	aal_list_t *devices = NULL;
-    
+
 	char *host_dev;
 	count_t dev_len = 0;
+	uint32_t dev_cnt = 0;
 	
 #ifdef HAVE_UNAME
 	struct utsname sysinfo;
 #endif
-	
+	int default_stripe = 1;
 	mkfs_behav_flags_t flags = 0;
-    
+
 	static struct option long_options[] = {
 		{"version", no_argument, NULL, 'V'},
 		{"help", no_argument, NULL, 'h'},
 		{"force", no_argument, NULL, 'f'},
 		{"yes", no_argument, NULL, 'y'},
 		{"block-size", required_argument, NULL, 'b'},
+		{"stripe-size", required_argument, NULL, 't'},
+		{"data-brick", no_argument, NULL, 'a'},
+		{"data-capacity", required_argument, NULL, 'c'},
 		{"label", required_argument, NULL, 'L'},
 		{"uuid", required_argument, NULL, 'U'},
 		{"lost-found", required_argument, NULL, 's'},
@@ -132,6 +168,8 @@ int main(int argc, char *argv[]) {
 		{"print-plugins", no_argument, NULL, 'l'},
 		{"override", required_argument, NULL, 'o'},
 		{"discard", no_argument, NULL, 'd'},
+		{"mirrors", no_argument, NULL, 'm'},
+		{"nr-segments", required_argument, NULL, 'n'},
 		{0, 0, 0, 0}
 	};
     
@@ -142,15 +180,11 @@ int main(int argc, char *argv[]) {
 		return USER_ERROR;
 	}
 
-	hint.blocks = 0;
-	hint.blksize = 0;
-	
+	memset(&hint, 0, sizeof(hint));
 	memset(override, 0, sizeof(override));
-	memset(hint.uuid, 0, sizeof(hint.uuid));
-	memset(hint.label, 0, sizeof(hint.label));
 
 	/* Parsing parameters */    
-	while ((c = getopt_long(argc, argv, "hVyfb:U:L:splo:d?",
+	while ((c = getopt_long(argc, argv, "hVyfb:t:U:L:n:r:spalo:dm?",
 				long_options, (int *)0)) != EOF) 
 	{
 		switch (c) {
@@ -179,6 +213,12 @@ int main(int argc, char *argv[]) {
 		case 'd':
 			flags |= BF_DISCARD;
 			break;
+		case 'm':
+			flags |= BF_MIRRORS;
+			break;
+		case 'a':
+			hint.is_data_brick = 1;
+			break;
 		case 'o':
 			aal_strncat(override, optarg,
 				    aal_strlen(optarg));
@@ -198,6 +238,28 @@ int main(int argc, char *argv[]) {
 				return USER_ERROR;	
 			}
 			break;
+		case 't':
+			/* Parsing stripe size */
+			if ((hint.stripe_size = misc_size2long(optarg)) == INVAL_DIG) {
+				aal_error("Invalid stripe size (%s).", optarg);
+				return USER_ERROR;
+			}
+			default_stripe = 0;
+			break;
+		case 'n':
+			/* Parsing nr segments */
+			if ((hint.num_segments = misc_str2long(optarg, 10)) == INVAL_DIG) {
+				aal_error("Invalid nr segments (%s).", optarg);
+				return USER_ERROR;
+			}
+			break;
+		case 'c':
+			/* Parsing data capacity */
+			if ((hint.data_capacity = misc_str2long(optarg, 10)) == INVAL_DIG) {
+				aal_error("Invalid data capacity (%s).", optarg);
+				return USER_ERROR;
+			}
+			break;
 		case 'U':
 			/* Parsing passed by user uuid */
 			if (aal_strlen(optarg) != 36) {
@@ -207,14 +269,15 @@ int main(int argc, char *argv[]) {
 			}
 #if defined(HAVE_LIBUUID) && defined(HAVE_UUID_UUID_H)
 			{
-			  if (uuid_parse(optarg, (unsigned char *)hint.uuid) < 0) {
+			  if (uuid_parse(optarg,
+					 (unsigned char *)hint.volume_uuid) < 0) {
 					aal_error("Invalid uuid was "
 						  "specified (%s).",
 						  optarg);
 					return USER_ERROR;
 				}
 			}
-#endif		
+#endif
 			break;
 		case 'L':
 			aal_strncpy(hint.label, optarg,
@@ -291,13 +354,14 @@ int main(int argc, char *argv[]) {
 		hint.blksize = 4096;
 	}
 #endif
-	
 	if (hint.blksize > REISER4_MAX_BLKSIZE) {
-		aal_error("Invalid blocksize (%u). It must not be greater then "
+		aal_error("Invalid blocksize (%u). It must not be greater than "
 			  "%u.", hint.blksize, REISER4_MAX_BLKSIZE);
-		return USER_ERROR;	
+		goto error_free_libreiser4;
 	}
-	
+	if (advise_nr_segments(&hint, flags & BF_FORCE) < 0)
+		goto error_free_libreiser4;
+
 #ifdef HAVE_UNAME
 	/* Guessing system type */
 	if (uname(&sysinfo) == -1) {
@@ -310,46 +374,37 @@ int main(int argc, char *argv[]) {
 			 sysinfo.release);
 	}
 #endif
-
-	/* Building list of devices the filesystem will be created on */
+	/*
+	 * Building list of devices the filesystem will be created on
+	 */
 	for (; optind < argc; optind++) {
 		if (stat(argv[optind], &st) == -1) {
-
-			if (misc_size2long(argv[optind]) != INVAL_DIG &&
-			    hint.blocks != 0)
-			{
-				aal_error("Filesystem length is already "
-					  "set to %llu.",
-					  (unsigned long long)hint.blocks);
-				continue;
-			}
-			
-			/* Checking device name for validness */
-			hint.blocks = misc_size2long(argv[optind]);
-			
-			if (hint.blocks != INVAL_DIG) {
-				/* Converting into fs blocksize blocks */
-				hint.blocks /= (hint.blksize / 1024);
-				/* Just to know that blocks was given. 0 
-				   means nothing was specified by user. */
-				if (!hint.blocks) hint.blocks = 1;
-			} else {
-				aal_error("%s is not a valid size nor an "
-					  "existent file.", argv[optind]);
-				goto error_free_libreiser4;
-			}
+			aal_error("Can't stat %s. %s.", argv[optind],
+				  strerror(errno));
+			goto error_free_libreiser4;
 		} else {
 			devices = aal_list_append(devices, argv[optind]);
+			dev_cnt ++;
 		}
 	}
+	/*
+	 * Set number of subvolumes and mirrors
+	 */
+	hint.num_subvols = 1;
 
+	if ((flags & BF_MIRRORS) && (dev_cnt != 0))
+		hint.num_replicas = dev_cnt - 1;
+	else
+		hint.num_replicas = 0;
+	dev_cnt = 0;
 	if (!(flags & BF_YES) && aal_list_len(devices)) {
 		if (!(gauge = aal_gauge_create(aux_gauge_handlers[GT_PROGRESS],
 					       NULL, NULL, 0, NULL)))
 			goto error_free_libreiser4;
 	}
-    
-	/* The loop through all devices */
+  	/*
+	 * Loop through all the accumulated devices
+	 */
 	aal_list_foreach_forward(devices, walk) {
     
 		host_dev = (char *)walk->data;
@@ -359,11 +414,12 @@ int main(int argc, char *argv[]) {
 				  strerror(errno));
 			goto error_free_libreiser4;
 		}
-    
-		/* Checking is passed device is a block device. If so, we check
-		   also is it whole drive or just a partition. If the device is
-		   not a block device, then we emmit exception and propose user
-		   to use -f flag to force. */
+		/*
+		 * Check if passed device is a block device. If so, we check
+		 * also is it whole drive or just a partition. If the device is
+		 * not a block device, then we emmit exception and propose user
+		 * to use -f flag to force
+		 */
 		if (!S_ISBLK(st.st_mode)) {
 			if (!(flags & BF_FORCE)) {
 				aal_error("Device %s is not block "
@@ -384,28 +440,50 @@ int main(int argc, char *argv[]) {
 				goto error_free_libreiser4;
 			}
 		}
-   
-		/* Checking if passed partition is mounted */
+   		/*
+		 * Check if passed partition is mounted
+		 */
 		if (misc_dev_mounted(host_dev) > 0 && !(flags & BF_FORCE)) {
 			aal_error("Device %s is mounted at the moment. "
 				  "Use -f to force over.", host_dev);
 			goto error_free_libreiser4;
 		}
-
-		/* Generating uuid if it was not specified and if libuuid is in use */
+		/*
+		 * Generate uuid if it was not specified and
+		 * if libuuid is in use
+		 */
 #if defined(HAVE_LIBUUID) && defined(HAVE_UUID_UUID_H)
-		if (uuid_is_null((unsigned char *)hint.uuid)) {
-			uuid_generate((unsigned char *)hint.uuid);
+		if (uuid_is_null((unsigned char *)hint.volume_uuid)) {
+			uuid_generate((unsigned char *)hint.volume_uuid);
+		}
+		if (uuid_is_null((unsigned char *)hint.subvol_uuid)) {
+			uuid_generate((unsigned char *)hint.subvol_uuid);
 		}
-
 		if (!(flags & BF_YES)) {
 			char uuid[256];
 
-			uuid_unparse((unsigned char *)hint.uuid, uuid);
-			aal_mess("Uuid %s will be used.", uuid);
+			uuid_unparse((unsigned char *)hint.volume_uuid, uuid);
+			aal_mess("Volume uuid %s will be used.", uuid);
+		}
+#else
+		if (flags & BF_MIRRORS ||
+		    hint.is_data_brick ||
+		    ((reiser4_vol_plug_t *)(reiser4_profile_plug(PROF_VOL)))->
+		    p.id.id == VOL_ASYM_ID) {
+			aal_error("uuid is required to create logical volumes");
+			goto error_free_libreiser4;
 		}
 #endif
-		/* Opening device */
+		/*
+		 * Initialize mkfs_id for fsck needs
+		 */
+		if (hint.mkfs_id == 0) {
+			srandom(time(0) + dev_cnt);
+			hint.mkfs_id = random();
+		}
+		if (flags & BF_MIRRORS)
+			hint.mirror_id = dev_cnt;
+
 		if (!(device = aal_device_open(&file_ops, host_dev, 
 					       512, O_RDWR))) 
 		{
@@ -413,13 +491,17 @@ int main(int argc, char *argv[]) {
 				  host_dev, strerror(errno));
 			goto error_free_libreiser4;
 		}
-    
-		/* Converting device length into fs blocksize blocks */
+    		/*
+		 * Convert device length into fs blocksize blocks
+		 */
 		dev_len = reiser4_format_len(device, hint.blksize);
-    
-		if (!hint.blocks)
-			hint.blocks = dev_len;
-	
+
+		if (flags & BF_MIRRORS &&
+		    hint.blocks != 0 && hint.blocks != dev_len) {
+			aal_error("Mirror can be created only on a device "
+				  "of the same length as the original has.");
+			goto error_free_device;
+		}
 		if (hint.blocks > dev_len) {
 			aal_error("Filesystem wouldn't fit into device "
 				  "%llu blocks long, %llu blocks required.",
@@ -427,8 +509,18 @@ int main(int argc, char *argv[]) {
 				  (unsigned long long)hint.blocks);
 			goto error_free_device;
 		}
+		if (hint.blocks == 0)
+			hint.blocks = dev_len;
 
-		/* Checking for non-intercative mode */
+		if (advise_stripe_size(&hint,
+				       default_stripe, flags & BF_FORCE) < 0)
+			goto error_free_device;
+
+		if (check_data_capacity(&hint, flags & BF_FORCE) < 0)
+			goto error_free_device;
+		/*
+		 * Check for non-intercative mode
+		 */
 		if (!(flags & BF_YES)) {
 			if (aal_yesno("Reiser4 is going to be created on %s.",
 				      host_dev) == EXCEPTION_OPT_NO)
@@ -459,8 +551,9 @@ int main(int argc, char *argv[]) {
 					 host_dev);
 			aal_gauge_touch(gauge);
 		}
-
-		/* Creating filesystem */
+		/*
+		 * Create a filesystem on the device
+		 */
 		if (!(fs = reiser4_fs_create(device, &hint))) {
 			aal_error("Can't create filesystem on %s.", 
 				  device->name);
@@ -498,7 +591,7 @@ int main(int argc, char *argv[]) {
 		}
 
 		/* Creating lost+found directory */
-		if (flags & BF_LOST) {
+		if ((flags & BF_LOST) && !hint.is_data_brick) {
 			reiser4_object_t *object;
 	    
 			if (!(object = reiser4_dir_create(fs->root,
@@ -515,24 +608,42 @@ int main(int argc, char *argv[]) {
 		if (gauge)
 			aal_gauge_done(gauge);
 
-		/* Zeroing uuid in order to force mkfs to generate it on its own
-		   for next device form built device list. */
-		aal_memset(hint.uuid, 0, sizeof(hint.uuid));
+		if (!(flags & BF_MIRRORS)) {
+			/*
+			 * The following parameters are independent,
+			 * so we zero them in order to force mkfs to
+			 * generate different ones for next device
+			 * form built device list
+			 */
+			aal_memset(hint.volume_uuid, 0, sizeof(hint.volume_uuid));
+			aal_memset(hint.label, 0, sizeof(hint.label));
+			hint.mkfs_id = 0;
+			hint.blocks = 0;
+		}
 
-		/* Zeroing out label, because all filesystems cannot have the
-		   same label. */
-		aal_memset(hint.label, 0, sizeof(hint.label));
+		/* Set data room size calculated by the rest of free space */
+		reiser4_set_data_capacity(fs, &hint);
+		/*
+		 * Set minimal number of occupied blocks - at any time number
+		 * of busy blocks on the partition has to be not smaller than
+		 * this value. We need this field in super-block because kernel
+		 * needs to know miniman number of occupied blocks, while being
+		 * not able to calculate it. Just because kernel is unaware of
+		 * backup blocks
+		 */
+		reiser4_set_min_occup(fs);
 
-		/* Zeroing fs_len in order to force mkfs on next turn to calc
-		   its size from actual device length. */
-		hint.blocks = 0;
-	
-		/* Freeing the root directory & fs.*/
+		aal_memset(hint.subvol_uuid, 0, sizeof(hint.subvol_uuid));
+		/*
+		 * Free the root directory & fs
+		 */
 		reiser4_object_close(fs->root);
 		reiser4_fs_close(fs);
-
-		/* Synchronizing device. If device we are using is a file device
-		   (libaal/file.c), then function fsync will be called. */
+		/*
+		 * Synchronizing device.
+		 * If device we are using is a file device (libaal/file.c),
+		 * then function fsync will be called
+		 */
 		if (aal_device_sync(device)) {
 			aal_error("Can't synchronize device %s.", 
 				  device->name);
@@ -540,6 +651,7 @@ int main(int argc, char *argv[]) {
 		}
 
 		aal_device_close(device);
+		dev_cnt ++;
 	}
     
 	/* Freeing the all used objects */
